==> RMAPPER_1.2.0.tar.gz: RMAPPER/R/allsrc.R <==
urlpath <- "http://genome.ufl.edu/mapper/"

setOldClass("data.frame")

setClass("mapperHits", representation(
        query="character", hits="data.frame"))

setGeneric("query", function(x)standardGeneric("query"))
setMethod("query", "mapperHits", function(x) {
 x@query
})
setGeneric("hits", function(x)standardGeneric("hits"))
setMethod("hits", "mapperHits", function(x) {
 x@hits
})

setMethod("show", "mapperHits", function(object) {
 cat(urlpath, "hits collection on query:\n", query(object), "\n")
 cat("There were ", nh <- nrow(hits(object)), "hits.\n")
 if (nh > 5) {
        cat("First 5 hits:\n")
        print(hits(object)[1:5,])
        }
 else print(hits(object))
})


reshapeMapper <- function(df) {
#
# assumes the file structure returned as of 20 Sep 2010
# the rectangular component has four records per hit:
# the first record is full and its last column is the binding site model,
# the second record is empty except for its last column, which encodes match between model and sequence,
# the third record is empty except for its last column which contains the binding site sequence,
# the fourth record is an empty line.
#
 nh <- nrow(df)/4
 nc <- ncol(df)
 kp <- df[seq(1,nh*4,4),]
 mat <- df[seq(2,nh*4,4),nc]
 sq <- df[seq(3,nh*4,4),nc]
 names(kp)[nc] <- "AlignModel"
 data.frame(kp, Match=mat, Seq=sq)
}

readMAPPER = function(stub = paste(urlpath,"db-rpc?",sep=""), ...) {
 parms = list(...)
 parmv = as.character(unlist(parms))
 nms = names(parms)
 sett = paste(nms,parmv,sep="=",collapse="&")
 x = readLines(paste(stub, sett, sep=""))
 if (x[1] == -1) stop(cat("generic internal error; notify ", urlpath, " maintainers"))
 else if (x[1] == -2) stop("missing gene identifier")
 else if (x[1] == -3) stop("missing models")
 tc = textConnection(x)
 tmp <- read.delim(tc,sep="\t", skip=1, h=TRUE)
 close(tc)
 new("mapperHits", query=sett, hits=reshapeMapper(tmp))
}

rmapperHelp = function(){
cat(readLines(paste(urlpath,"db-rpc?",sep="")), sep="\n")
}

rmapperFactorTable = function(tf){
cat(readLines(paste(urlpath,"db-rpc?list=",tf,sep="")), sep="\n")
}

==> RMAPPER_1.8.0.tar.gz: RMAPPER/R/allsrc.R <==
urlpath <- "http://genome.ufl.edu/mapper/"

setOldClass("data.frame")

setClass("mapperHits", representation(
        query="character", hits="data.frame"))

setGeneric("query", function(x)standardGeneric("query"))
setMethod("query", "mapperHits", function(x) {
 x@query
})
setGeneric("hits", function(x)standardGeneric("hits"))
setMethod("hits", "mapperHits", function(x) {
 x@hits
})

setMethod("show", "mapperHits", function(object) {
 cat(urlpath, "hits collection on query:\n", query(object), "\n")
 cat("There were ", nh <- nrow(hits(object)), "hits.\n")
 if (nh > 5) {
        cat("First 5 hits:\n")
        print(hits(object)[1:5,])
        }
 else print(hits(object))
})


reshapeMapper <- function(df) {
#
# assumes the file structure returned as of 20 Sep 2010
# the rectangular component has four records per hit:
# the first record is full and its last column is the binding site model,
# the second record is empty except for its last column, which encodes match between model and sequence,
# the third record is empty except for its last column which contains the binding site sequence,
# the fourth record is an empty line.
#
 nh <- nrow(df)/4
 nc <- ncol(df)
 kp <- df[seq(1,nh*4,4),]
 mat <- df[seq(2,nh*4,4),nc]
 sq <- df[seq(3,nh*4,4),nc]
 names(kp)[nc] <- "AlignModel"
 data.frame(kp, Match=mat, Seq=sq)
}

readMAPPER = function(stub = paste(urlpath,"db-rpc?",sep=""), ...) {
 parms = list(...)
 parmv = as.character(unlist(parms))
 nms = names(parms)
 sett = paste(nms,parmv,sep="=",collapse="&")
 x = readLines(paste(stub, sett, sep=""))
 if (x[1] == 0) stop("no hits returned")
 else if (x[1] == -1) stop(cat("generic internal error; notify ", urlpath, " maintainers"))
 else if (x[1] == -2) stop("missing gene identifier")
 else if (x[1] == -3) stop("missing models")
 tc = textConnection(x)
 tmp <- read.delim(tc,sep="\t", skip=1, h=TRUE)
 close(tc)
 new("mapperHits", query=sett, hits=reshapeMapper(tmp))
}

rmapperHelp = function(){
cat(readLines(paste(urlpath,"db-rpc?",sep="")), sep="\n")
}

rmapperFactorTable = function(tf){
cat(readLines(paste(urlpath,"db-rpc?list=",tf,sep="")), sep="\n")
}
